@@ -27,10 +27,10 @@ if ($pass_admin_errata == "NO") {
 
 
 
-$voto_tot = "";
-$voto_giornale = "";
-$punti_tot = "";
-$voti_tot = "";
+$voto_tot = array();
+$voto_giornale = array();
+$punti_tot = array();
+$voti_tot = array();
 $modificatori = array();
 $num2 = 0;
 $num_giornata = substr($giornata,8);
@@ -134,7 +134,7 @@ $voto_giornale[$num_calciatore] = togli_acapo($voto_giornale[$num_calciatore]) +
 $file_giornata = file("$percorso_cartella_dati/$giornata");
 $num_linee_file_giornata = count($file_giornata);
 $num_partite = 0;
-$partite = "";
+$partite = array();
 for($num1 = 0 ; $num1 < $num_linee_file_giornata; $num1++) {
 $linea = togli_acapo($file_giornata[$num1]);
 if (substr($linea,0,12) == "#@& data #@&") $data = substr($linea,12);
@@ -229,7 +229,7 @@ $schema_attuale = substr_replace($schema_attuale,$num_ruolo_attuale,$pos_ruolo,1
 
 # punteggio dei panchinari
 $entrati_dalla_panchina = 0;
-$calciatore_entrato = "";
+$calciatore_entrato = array();
 $linea_inizio_panchina = $num2 + 1;
 
 # Se si effettuano sostituzioni per ruoli
@@ -449,13 +449,13 @@ fwrite($filegiornata,"#@& fine punteggi #@&
 if ($tipo_campionato == "P") {
 arsort ($voti_tot);
 reset ($voti_tot);
-$posizione = "";
+$posizione = array();
 $num1 = 1;
-while (list ($key, $val) = each ($voti_tot)) {
+foreach ($voti_tot as $key => $val) {
 $posizione[$num1] = $key;
 $voti_posizione[$num1] = $val;
 $num1++;
-} # fine while (list ($key, $val) = each ($voti_tot))
+} # fine foreach ($voti_tot as $key => $val)
 for($num1 = 1 ; $num1 <= $num_giocatori; $num1++) {
 $pos_alta = $num1;
 $pos_bassa = $num1;
