@@ -20,26 +20,10 @@
 ##################################################################################
 
 
-ignore_user_abort(1);
-
-# nel caso fosse settato register_globals = Off
-if (@is_array($_POST)) reset($_POST);
-for($num1 = 0 ; $num1 < count($_POST); $num1++) {
-$var_POST = key($_POST);
-$$var_POST = $_POST[$var_POST];
-next($_POST);
-} # fine for $num1
-if (@is_array($_GET)) reset($_GET);
-for($num1 = 0 ; $num1 < count($_GET); $num1++) {
-$var_GET = key($_GET);
-$$var_GET = $_GET[$var_GET];
-next($_GET);
-} # fine for $num1
-
 
 # Posizione delle cartelle "dati" e "scontri" rispetto alla cartella di fantacalciobazar. 
 # Cambiare SOLO SE queste cartelle non si trovano nella stessa cartella degli alti file 
-# di fantacalciobazar! Non mettere lo slash alla fine. La cartella "voti"  dove vengono 
+# di fantacalciobazar! Non mettere lo slash alla fine. La cartella "voti" è dove vengono 
 # posizionati i file votiXX.txt e calciatori.txt, di default la stessa "dati".
 $percorso_cartella_dati = "./dati";
 $percorso_cartella_scontri = "./scontri";
@@ -47,7 +31,6 @@ $percorso_cartella_voti = $percorso_cartella_dati;
 
 
 include("$percorso_cartella_dati/dati.php");
-include("./funzioni.php");
 $pass_admin_errata = "SI";
 if ($nome_utente == "admin") {
 $pass_errata = "SI";
