@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -91,9 +91,9 @@ echo "</select></form></td>";
 
 $tab_formazioni = "<tr>";
 $num_colonne = 0;
-$punti = "";
-$voti = "";
-$scontri = "";
+$punti = array();
+$voti = array();
+$scontri = array();
 $data = "";
 $num2 = 0;
 $leggendo_formazioni = "SI";
@@ -103,7 +103,8 @@ $leggendo_scontri = "NO";
 $voti_esistenti = "NO";
 
 if ($giornata_ultima) $file_giornata = file("$percorso_cartella_dati/$giornata");
-$num_linee_file_giornata = count($file_giornata);
+if (@is_array($file_giornata)) $num_linee_file_giornata = count($file_giornata);
+else $num_linee_file_giornata = 0;
 for($num1 = 0 ; $num1 < $num_linee_file_giornata; $num1++) {
 $linea = togli_acapo($file_giornata[$num1]);
 if (substr($linea,0,12) == "#@& data #@&") $data = substr($linea,12);
@@ -210,7 +211,8 @@ $num_colonne++;
 $tab_formazioni .= "<td>$soprannome_squadra di $giocatore<br><br>";
 $formazione = "formazione_$giocatore";
 $formazione = $$formazione;
-$num_linee_formazione = count($formazione);
+if (@is_array($formazione)) $num_linee_formazione = count($formazione);
+else $num_linee_formazione = 0;
 for ($num2 = 0 ; $num2 < $num_linee_formazione; $num2++) {
 $formazione[$num2] = preg_replace("/ /","&nbsp;",$formazione[$num2]);
 $tab_formazioni .= $formazione[$num2]."<br>";
@@ -271,9 +273,9 @@ $voto[$dati_voti[0]] = $dati_voti[1];
 } # fine for $num1
 arsort ($voto);
 reset ($voto);
-while (list ($key, $val) = each ($voto)) {
+foreach ($voto as $key => $val) {
 echo $nome_sqadra_memo[$key].": $val<br>";
-} # fine while
+} # fine foreach
 echo "</td>";
 
 if ($tipo_campionato == "P") {
@@ -286,9 +288,9 @@ $punteggio[$dati_punteggi[0]] = $dati_punteggi[1];
 } # fine for $num1
 arsort ($punteggio);
 reset ($punteggio);
-while (list ($key, $val) = each ($punteggio)) {
+foreach ($punteggio as $key => $val) {
 echo "$val<br>";
-} # fine while
+} # fine foreach
 echo "</td>";
 } # fine if ($tipo_campionato == "P")
 
@@ -330,9 +332,9 @@ $punti[$dati_punteggio[0]] = ($punti[$dati_punteggio[0]] + $dati_punteggio[1]);
 echo "<td>&nbsp;&nbsp;</td><td><font color=\"red\">Classifica_alla_giornata_$num_giornata_campionato:</font><br>";
 arsort ($punti);
 reset ($punti);
-while (list ($key, $val) = each ($punti)) {
+foreach ($punti as $key => $val) {
 echo $nome_sqadra_memo[$key].": $val<br>";
-} # fine while
+} # fine foreach
 echo "</td>";
 } # fine if ($tipo_campionato != "N")
 echo "</tr></table>";
