@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -89,7 +89,8 @@ echo "</select>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</form></td>";
 } # fine if ($mostra_giornate_in_mercato == "SI")
 if ($num_calciatori_scambiabili > 0) {
 $scambi_proposti = @file("$percorso_cartella_dati/scambi.txt");
-$num_scambi_proposti = count($scambi_proposti);
+if (@is_array($scambi_proposti)) $num_scambi_proposti = count($scambi_proposti);
+else $num_scambi_proposti = 0;
 for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
 $dati_scambio = explode(",", $scambi_proposti[$num1]);
 if ($nome_utente == $dati_scambio[4]) {
@@ -122,7 +123,8 @@ echo "<td align=\"center\"><form  accept-charset=\"utf-8\" method=\"post\" actio
 
 
 $calciatori = @file("$percorso_cartella_dati/mercato.txt");
-$num_calciatori = count($calciatori);
+if (@is_array($calciatori)) $num_calciatori = count($calciatori);
+else $num_calciatori = 0;
 
 if ($formato_pda == "SI") echo "
 <table width=3 border=1 cellspacing=0 cellpadding=1 align=\"center\" bgcolor=\"$sfondo_tab\">
@@ -246,7 +248,7 @@ $riga_tab_mercato[$numero] = "<tr><td>$numero</td>
 if (@is_array($sec_restanti_vett)) {
 asort ($sec_restanti_vett);
 reset ($sec_restanti_vett);
-while (list($key, $val) = each($sec_restanti_vett)) echo $riga_tab_mercato[$key];
+foreach ($sec_restanti_vett as $key => $val) echo $riga_tab_mercato[$key];
 } # fine if (@is_array($sec_restanti_vett))
 echo "$tab_comprati</table>";
 
