@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -45,7 +45,8 @@ echo "
 <center><font size=+2>Messaggi</font></center>";
 
 $messaggi = @file("$percorso_cartella_dati/messaggi.txt");
-$num_messaggi = count($messaggi);
+if (@is_array($messaggi)) $num_messaggi = count($messaggi);
+else $num_messaggi = 0;
 if ($tutti_i_messaggi == "SI") $num_iniziale = 0;
 else $num_iniziale = $num_messaggi - 25;
 if ($num_iniziale < 0) $num_iniziale = 0;
