@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -41,7 +41,8 @@ echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcol
 <td>__Tempo_rimasto__</td></tr>";
 
 $calciatori = @file("$percorso_cartella_dati/mercato.txt");
-$num_calciatori = count($calciatori);
+if (@is_array($calciatori)) $num_calciatori = count($calciatori);
+else $num_calciatori = 0;
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 $dati_calciatore = explode(",", $calciatori[$num1]);
 $numero = $dati_calciatore[0];
