@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -30,7 +30,8 @@ if ($pass_errata != "SI") {
 if ($sfondo_tab == "") $sfondo_tab = "#b9ccd4";
 
 $calciatori = @file("$percorso_cartella_dati/mercato.txt");
-$num_calciatori = count($calciatori);
+if (@is_array($calciatori)) $num_calciatori = count($calciatori);
+else $num_calciatori = 0;
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 $dati_calciatore = explode(",", $calciatori[$num1]);
 $numero = $dati_calciatore[0];
@@ -48,7 +49,8 @@ echo "<center><font size=+2>Proposte di scambio</font></center><br><font size=-1
 <td><font size=-1>&nbsp;</font></td></tr>";
 
 $scambi_proposti = @file("$percorso_cartella_dati/scambi.txt");
-$num_scambi_proposti = count($scambi_proposti);
+if (@is_array($scambi_proposti)) $num_scambi_proposti = count($scambi_proposti);
+else $num_scambi_proposti = 0;
 
 for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
 $dati_scambio = explode(",", $scambi_proposti[$num1]);
