@@ -36,11 +36,12 @@ else {
 $num_calciatori_posseduti = 0;
 $num_calciatori_effettivi = 0;
 $soldi_spesi = 0;
-$calciatori_utente = "";
+$calciatori_utente = array();
+$gia_offerti_utente = array();
 $num_calciatori_posseduti_altro = 0;
 $num_calciatori_effettivi_altro = 0;
 $soldi_spesi_altro = 0;
-$calciatori_altro = "";
+$calciatori_altro = array();
 $num_calciatori_offerti = 0;
 $num_calciatori_richiesti = 0;
 $lista_ric = "";
