@@ -36,7 +36,7 @@ $trovato = "NO";
 $num_calciatori_posseduti = 0;
 $num_calciatori_effettivi = 0;
 $soldi_spesi = 0;
-$calciatori_utente = "";
+$calciatori_utente = array();
 $num_calciatori_posseduti_altro = 0;
 $num_calciatori_effettivi_altro = 0;
 $soldi_spesi_altro = 0;
