@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -101,7 +101,7 @@ if ($soprannome_squadra) echo "<b>$soprannome_squadra</b>";
 else echo "Squadra";
 echo " di $giocatore</font></center>";
 $contatore_calciatori = 0;
-$lista_calciatori = "";
+$lista_calciatori = array();
 $soldi_spesi = 0;
 $num_calciatori_posseduti = 0;
 $linea_offerto = "";
@@ -119,7 +119,8 @@ $tab_offerte = "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"cent
 <td>__Tempo_rimasto__</td></tr>";
 
 $calciatori = @file("$percorso_cartella_dati/mercato.txt");
-$num_calciatori = count($calciatori);
+if (@is_array($calciatori)) $num_calciatori = count($calciatori);
+else $num_calciatori = 0;
 for ($num2 = 0 ; $num2 < $num_calciatori ; $num2++) {
 $dati_calciatore = explode(",", $calciatori[$num2]);
 $numero = $dati_calciatore[0];
