@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -26,9 +26,13 @@ include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI") {
 
 
+if ($num_colonna_gol_segnati and ($bonus_gol_portiere or $bonus_gol_difensore or $bonus_gol_centrocampista or $bonus_gol_fantasista or $bonus_gol_attaccante)) $calcola_bonus = 1;
+else $calcola_bonus = 0;
+
 $partite_giocate = 0;
 $somma_voti_tot = 0;
 $somma_voti_giornale = 0;
+$gol_calciatore = 0;
 for ($num1 = "01" ; $num1 < 100 ; $num1++) {
 if (strlen($num1) == 1) $num1 = "0".$num1;
 if ($voti = @file("$percorso_cartella_voti/voti$num1.txt")) {
@@ -44,26 +48,18 @@ $voto_tot = str_replace(",",".",$voto_tot);
 $voto_giornale = $dati_voto[($num_colonna_votogiornale_file_voti-1)];
 $voto_giornale = togli_acapo($voto_giornale);
 $voto_giornale = str_replace(",",".",$voto_giornale);
-if ($voto_giornale or ($voto_tot and $voto_tot <= 3)) {
+if ((double) $voto_giornale or ((double) $voto_tot and (double) $voto_tot <= 3)) {
 $partite_giocate++;
 $somma_voti_tot = $somma_voti_tot + $voto_tot;
 $somma_voti_giornale = $somma_voti_giornale + $voto_giornale;
-} # fine if ($voto_giornale or ($voto_tot and $voto_tot <= 3))
+if ($calcola_bonus) $gol_calciatore += (integer) togli_acapo($dati_voto[($num_colonna_gol_segnati - 1)]);
+} # fine if ((double) $voto_giornale or ((double) $voto_tot and (double) $voto_tot <= 3))
 break;
 } # fine if ($num_calciatore == $num_calciatore_voto)
 } # fine if ($voti = @file("$percorso_cartella_voti/voti$num1.txt"))
 } # fine for $num2
 } # fine for $num1
 
-if ($partite_giocate != 0) {
-$media_giornale = round(($somma_voti_giornale / $partite_giocate),2);
-$media_punti = round(($somma_voti_tot / $partite_giocate),2);
-} # fine if ($partite_giocate != 0)
-else {
-$media_giornale = 0;
-$media_punti = 0;
-} # fine else if ($partite_giocate != 0)
-
 $calciatori = file("$percorso_cartella_voti/calciatori.txt");
 $num_calciatori = count($calciatori);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
@@ -79,6 +75,8 @@ $squadra = $dati_calciatore[($num_colonna_squadra_file_calciatori-1)];
 $squadra = togli_acapo($squadra);
 $squadra = preg_replace("/\"/","",$squadra);
 } # fine if ($num_colonna_squadra_file_calciatori != 0)
+if ($num_colonna_attributo_fantasista) $attr_fantasista = $dati_calciatore[($num_colonna_attributo_fantasista-1)];
+else $attr_fantasista = 0;
 $s_ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
 $s_ruolo = togli_acapo($s_ruolo);
 $ruolo = $s_ruolo;
@@ -88,10 +86,28 @@ if ($s_ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
 if ($s_ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
 if ($s_ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
 if ($s_ruolo == $simbolo_attaccante_file_calciatori) $ruolo = "A";
+if ($considera_fantasisti_come == "F" and $attr_fantasista) $ruolo = "F";
+if ($attr_fantasista and $ruolo != "F") $ruolo .= "<small>(F)</small>";
 break;
 } # fine if ($num_calciatore == $numero)
 } # fine for $num1
 
+if ($partite_giocate != 0) {
+if ($calcola_bonus) {
+if ($ruolo == "P") $somma_voti_tot += $gol_calciatore * (double) $bonus_gol_portiere;
+if ($ruolo == "D") $somma_voti_tot += $gol_calciatore * (double) $bonus_gol_difensore;
+if ($ruolo == "C") $somma_voti_tot += $gol_calciatore * (double) $bonus_gol_centrocampista;
+if (strstr($ruolo,"F")) $somma_voti_tot += $gol_calciatore * (double) $bonus_gol_fantasista;
+if ($ruolo == "A") $somma_voti_tot += $gol_calciatore * (double) $bonus_gol_attaccante;
+} # fine if ($calcola_bonus)
+$media_giornale = round(($somma_voti_giornale / $partite_giocate),2);
+$media_punti = round(($somma_voti_tot / $partite_giocate),2);
+} # fine if ($partite_giocate != 0)
+else {
+$media_giornale = 0;
+$media_punti = 0;
+} # fine else if ($partite_giocate != 0)
+
 echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
 <tr><td>Num.</td>
 <td>_____________Nome_____________</td>
@@ -99,15 +115,18 @@ echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcol
 if ($squadra) echo "<td align=\"center\">Squadra</td>";
 echo "<td align=\"center\"><font size=-1>Partite giocate</font></td>
 <td align=\"center\"><font size=-2>Media voti giornale</font></td>
-<td align=\"center\"><font size=-1>Media punti</font></td></tr>
+<td align=\"center\"><font size=-1>Media punti</font></td>";
+if ($calcola_bonus) echo "<td align=\"center\"><font size=-1>Gol segnati</font></td>";
+echo "</tr>
 <tr><td align=\"center\">$num_calciatore</td>
 <td>$nome</td>
 <td align=\"center\">$ruolo</td>";
 if ($squadra) echo "<td align=\"center\">$squadra</td>";
 echo "<td align=\"center\">$partite_giocate</td>
 <td align=\"center\">$media_giornale</td>
-<td align=\"center\">$media_punti</td>
-</tr></table>";
+<td align=\"center\">$media_punti</td>";
+if ($calcola_bonus) echo "<td align=\"center\">$gol_calciatore</td>";
+echo "</tr></table>";
 
 echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"tab_calciatori.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
