@@ -202,7 +202,7 @@ echo "<table border=2 cellspacing=0 cellpadding=5>
 <td align=\"center\">&nbsp;P&nbsp;</td><td align=\"center\">G.F.</td><td align=\"center\">G.S.</td><td align=\"center\">D.R.</td></tr>";
 arsort ($somma_punti);
 reset ($somma_punti);
-while (list($key, $val) = each($somma_punti)) {
+foreach ($somma_punti as $key => $val) {
 echo "<tr><td align=\"center\">".$nome_sqadra_memo[$key]."</td>
 <td align=\"center\">".norm_zero($somma_punti[$key])."</td>
 <td align=\"center\">".norm_zero($somma_vinte[$key])."</td>
@@ -211,7 +211,7 @@ echo "<tr><td align=\"center\">".$nome_sqadra_memo[$key]."</td>
 <td align=\"center\">".norm_zero($somma_gol_fatti[$key])."</td>
 <td align=\"center\">".norm_zero($somma_gol_subiti[$key])."</td>
 <td align=\"center\">".norm_zero($somma_gol_fatti[$key] - $somma_gol_subiti[$key])."</td></tr>";
-} # fine while (list($key, $val) = each($somma_punti))
+} # fine foreach ($somma_punti as $key => $val)
 echo "</table><br>";
 } # fine if (@is_array($somma_punti))
 
