@@ -19,6 +19,7 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ##################################################################################
 
+include('./include/funzioni.php');
 include("./controlla_pass.php");
 if ($pass_errata != "SI") {
 
@@ -56,7 +57,7 @@ $posizione = $num1;
 } # fine if ($proprietario == $nome_utente)
 } # fine for $num1
 
-$verifica_num = ereg_replace("[0-9]","",$valore_rivendita);
+$verifica_num = preg_replace("/[0-9]/","",$valore_rivendita);
 if ($verifica_num != "") {
 $trovato = "NO";
 $frase = "L'offerta deve essere un numero intero.<br>";
@@ -64,14 +65,15 @@ $frase = "L'offerta deve essere un numero intero.<br>";
 
 if ($stato_mercato == "C" or $stato_mercato == "S") {
 $trovato = "NO";
-$frase .= "Il mercato  <b>chiuso</b> o <b>sospeso</b> in questo momento.<br>";
+$frase .= "Il mercato è <b>chiuso</b> o <b>sospeso</b> in questo momento.<br>";
 } # fine if ($stato_mercato == "C" or $stato_mercato == "S")
 
 if ($trovato == "NO") {
 echo "<html>
-<header>
+<head>
+<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" >
 <title> Fantacalcio </title>
-</header>
+</head>
 <body bgcolor=#ffffff>
 Non puoi vendere questo calciatore.<br>$frase";
 } # fine if ($trovato == "NO")
@@ -118,15 +120,16 @@ flock($filesquadra,3);
 flock($lockutente,3);
 
 echo "<html>
-<header>
+<head>
+<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" >
 <title> fantacalcio </title>
 <meta http-equiv=\"refresh\" content=\"1; url=squadra.php?nome_squadra=$nome_utente&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">
-</header>
+</head>
 <body bgcolor=#ffffff>
 Calciatore rimesso sul mercato per <b>$valore_rivendita</b> Fanta-Euro!<br>";
 } # fine else if ($trovato == "NO")
 
-echo "<center><form method=\"post\" action=\"squadra.php\">
+echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"squadra.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_utente\">
