@@ -20,6 +20,7 @@
 ##################################################################################
 
 
+include('./include/funzioni.php');
 include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI") {
@@ -30,7 +31,7 @@ if (@is_file("$percorso_cartella_dati/sondaggio.php")) {
 include("$percorso_cartella_dati/sondaggio.php");
 $voti_giocatore = "voti_".$nome_utente;
 $voti_giocatore = count($$voti_giocatore);
-if ($vota and ($voti_consentiti == 0 or $voti_giocatore < $voti_consentiti)) {
+if ($vota and $voto and ($voti_consentiti == 0 or $voti_giocatore < $voti_consentiti)) {
 $lock = fopen("$percorso_cartella_dati/sondaggio.lock","w+");
 flock($lock,2);
 include("$percorso_cartella_dati/sondaggio.php");
@@ -102,7 +103,7 @@ next($pass);
 
 } # fine if (@is_file("$percorso_cartella_dati/sondaggio.php"))
 
-echo "<center><form method=\"post\" action=\"./messaggi.php\">
+echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"./messaggi.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
@@ -113,4 +114,4 @@ echo "<center><form method=\"post\" action=\"./messaggi.php\">
 } # fine if ($pass_errata != "SI")
 
 include("$percorso_cartella_dati/foot.php");
-?>
\ No newline at end of file
+?>
